==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingMembers.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ResourceSetBindingMember;
import com.okta.sdk.resource.model.ResourceSetBindingMembersLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingMembers
 */
@JsonPropertyOrder({ ResourceSetBindingMembers.JSON_PROPERTY_MEMBERS, ResourceSetBindingMembers.JSON_PROPERTY_LINKS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSetBindingMembers implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MEMBERS = "members";
    private List<ResourceSetBindingMember> members = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private ResourceSetBindingMembersLinks links;

    public ResourceSetBindingMembers() {
    }

    public ResourceSetBindingMembers members(List<ResourceSetBindingMember> members) {

        this.members = members;
        return this;
    }

    public ResourceSetBindingMembers addmembersItem(ResourceSetBindingMember membersItem) {
        if (this.members == null) {
            this.members = new ArrayList<>();
        }
        this.members.add(membersItem);
        return this;
    }

    /**
     * Get members
     *
     * @return members
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSetBindingMember> getMembers() {
        return members;
    }

    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMembers(List<ResourceSetBindingMember> members) {
        this.members = members;
    }

    public ResourceSetBindingMembers links(ResourceSetBindingMembersLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ResourceSetBindingMembersLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(ResourceSetBindingMembersLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingMembers resourceSetBindingMembers = (ResourceSetBindingMembers) o;
        return Objects.equals(this.members, resourceSetBindingMembers.members)
                && Objects.equals(this.links, resourceSetBindingMembers.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(members, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingMembers {\n");
        sb.append("    members: ").append(toIndentedString(members)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingMembers.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ResourceSetBindingMember;
import com.okta.sdk.resource.model.ResourceSetBindingMembersLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingMembers
 */
@JsonPropertyOrder({ ResourceSetBindingMembers.JSON_PROPERTY_MEMBERS, ResourceSetBindingMembers.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ResourceSetBindingMembers implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MEMBERS = "members";
    private List<ResourceSetBindingMember> members = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private ResourceSetBindingMembersLinks links;

    public ResourceSetBindingMembers() {
    }

    public ResourceSetBindingMembers members(List<ResourceSetBindingMember> members) {

        this.members = members;
        return this;
    }

    public ResourceSetBindingMembers addmembersItem(ResourceSetBindingMember membersItem) {
        if (this.members == null) {
            this.members = new ArrayList<>();
        }
        this.members.add(membersItem);
        return this;
    }

    /**
     * Get members
     *
     * @return members
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSetBindingMember> getMembers() {
        return members;
    }

    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMembers(List<ResourceSetBindingMember> members) {
        this.members = members;
    }

    public ResourceSetBindingMembers links(ResourceSetBindingMembersLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ResourceSetBindingMembersLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(ResourceSetBindingMembersLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingMembers resourceSetBindingMembers = (ResourceSetBindingMembers) o;
        return Objects.equals(this.members, resourceSetBindingMembers.members)
                && Objects.equals(this.links, resourceSetBindingMembers.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(members, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingMembers {\n");
        sb.append("    members: ").append(toIndentedString(members)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
